@@ -169,98 +169,6 @@ fragment messageEventFragment on MessageEvent {
 )
 
 
-EXECUTE_PLAN_MUTATION = (
-    """
-mutation(
-  $executionParams: ExecutionParams!
-  $retries: Retries
-) {
-  executePlan(
-    executionParams: $executionParams,
-    retries: $retries,
-  ) {
-    __typename
-    ... on InvalidStepError {
-      invalidStepKey
-    }
-    ... on PipelineConfigValidationInvalid {
-      pipelineName
-      errors {
-        __typename
-        message
-        path
-        reason
-      }
-    }
-    ... on PipelineNotFoundError {
-      message
-      pipelineName
-    }
-    ... on PythonError {
-      message
-      stack
-    }
-    ... on ExecutePlanSuccess {
-      pipeline {
-        name
-      }
-      hasFailures
-      stepEvents {
-        __typename
-        ...stepEventFragment
-      }
-    }
-  }
-}
-"""
-    + STEP_EVENT_FRAGMENTS
-)
-
-RAW_EXECUTE_PLAN_MUTATION = """
-mutation(
-  $executionParams: ExecutionParams!
-  $retries: Retries
-) {
-  executePlan(
-    executionParams: $executionParams,
-    retries: $retries,
-  ) {
-    __typename
-    ... on InvalidStepError {
-      invalidStepKey
-    }
-    ... on PipelineConfigValidationInvalid {
-      pipelineName
-      errors {
-        __typename
-        message
-        path
-        reason
-      }
-    }
-    ... on PipelineNotFoundError {
-      message
-      pipelineName
-    }
-    ... on PythonError {
-      message
-      stack
-      cause {
-          message
-          stack
-      }
-    }
-    ... on ExecutePlanSuccess {
-      pipeline {
-        name
-      }
-      hasFailures
-      rawEventRecords
-    }
-  }
-}
-"""
-
 SUBSCRIPTION_QUERY = (
     MESSAGE_EVENT_FRAGMENTS
     + """
