@@ -153,6 +153,6 @@ def get_stats(graphene_info, run_id):
     return graphene_info.schema.type_named("PipelineRunStatsSnapshot")(stats)
 
 
-def get_step_stats(graphene_info, run_id):
-    step_stats = graphene_info.context.instance.get_run_step_stats(run_id)
+def get_step_stats(graphene_info, run_id, step_keys=None):
+    step_stats = graphene_info.context.instance.get_run_step_stats(run_id, step_keys)
     return [graphene_info.schema.type_named("PipelineRunStepStats")(stats) for stats in step_stats]
