@@ -1,3 +1,7 @@
+from dagster import check
+from dagster.core.host_representation import ExternalPartitionSet, RepositoryHandle
+from dagster.core.storage.pipeline_run import PipelineRunsFilter
+from dagster.utils import merge_dicts
 from dagster_graphql import dauphin
 from dagster_graphql.implementation.fetch_partition_sets import (
     get_partition_by_name,
@@ -12,31 +16,32 @@ from dagster_graphql.schema.errors import (
     DauphinPythonError,
 )
 
-from dagster import check
-from dagster.core.host_representation import ExternalPartitionSet, RepositoryHandle
-from dagster.core.storage.pipeline_run import PipelineRunsFilter
-
 
 class DauphinPartition(dauphin.ObjectType):
     class Meta(object):
-        name = 'Partition'
+        name = "Partition"
 
     name = dauphin.NonNull(dauphin.String)
     partition_set_name = dauphin.NonNull(dauphin.String)
     solid_selection = dauphin.List(dauphin.NonNull(dauphin.String))
     mode = dauphin.NonNull(dauphin.String)
-    runConfigOrError = dauphin.NonNull('PartitionRunConfigOrError')
-    tagsOrError = dauphin.NonNull('PartitionTagsOrError')
-    runs = dauphin.non_null_list('PipelineRun')
+    runConfigOrError = dauphin.NonNull("PartitionRunConfigOrError")
+    tagsOrError = dauphin.NonNull("PartitionTagsOrError")
+    runs = dauphin.Field(
+        dauphin.non_null_list("PipelineRun"),
+        filter=dauphin.Argument("PipelineRunsFilter"),
+        cursor=dauphin.String(),
+        limit=dauphin.Int(),
+    )
 
     def __init__(self, external_repository_handle, external_partition_set, partition_name):
         self._external_repository_handle = check.inst_param(
-            external_repository_handle, 'external_respository_handle', RepositoryHandle
+            external_repository_handle, "external_respository_handle", RepositoryHandle
         )
         self._external_partition_set = check.inst_param(
-            external_partition_set, 'external_partition_set', ExternalPartitionSet
+            external_partition_set, "external_partition_set", ExternalPartitionSet
         )
-        self._partition_name = check.str_param(partition_name, 'partition_name')
+        self._partition_name = check.str_param(partition_name, "partition_name")
 
         super(DauphinPartition, self).__init__(
             name=partition_name,
@@ -61,45 +66,57 @@ class DauphinPartition(dauphin.ObjectType):
             self._partition_name,
         )
 
-    def resolve_runs(self, graphene_info):
-        runs_filter = PipelineRunsFilter(
-            tags={
-                'dagster/partition_set': self._external_partition_set.name,
-                'dagster/partition': self._partition_name,
-            }
+    def resolve_runs(self, graphene_info, **kwargs):
+        filters = kwargs.get("filter")
+        partition_tags = {
+            "dagster/partition_set": self._external_partition_set.name,
+            "dagster/partition": self._partition_name,
+        }
+        if filters is not None:
+            filters = filters.to_selector()
+            runs_filter = PipelineRunsFilter(
+                run_ids=filters.run_ids,
+                pipeline_name=filters.pipeline_name,
+                status=filters.status,
+                tags=merge_dicts(filters.tags, partition_tags),
+            )
+        else:
+            runs_filter = PipelineRunsFilter(tags=partition_tags)
+
+        return get_runs(
+            graphene_info, runs_filter, cursor=kwargs.get("cursor"), limit=kwargs.get("limit")
         )
-        return get_runs(graphene_info, runs_filter)
 
 
 class DauphinPartitions(dauphin.ObjectType):
     class Meta(object):
-        name = 'Partitions'
+        name = "Partitions"
 
-    results = dauphin.non_null_list('Partition')
+    results = dauphin.non_null_list("Partition")
 
 
 class DauphinPartitionSet(dauphin.ObjectType):
     class Meta(object):
-        name = 'PartitionSet'
+        name = "PartitionSet"
 
     name = dauphin.NonNull(dauphin.String)
     pipeline_name = dauphin.NonNull(dauphin.String)
     solid_selection = dauphin.List(dauphin.NonNull(dauphin.String))
     mode = dauphin.NonNull(dauphin.String)
     partitionsOrError = dauphin.Field(
-        dauphin.NonNull('PartitionsOrError'),
+        dauphin.NonNull("PartitionsOrError"),
         cursor=dauphin.String(),
         limit=dauphin.Int(),
         reverse=dauphin.Boolean(),
     )
-    partition = dauphin.Field('Partition', partition_name=dauphin.NonNull(dauphin.String))
+    partition = dauphin.Field("Partition", partition_name=dauphin.NonNull(dauphin.String))
 
     def __init__(self, external_repository_handle, external_partition_set):
         self._external_repository_handle = check.inst_param(
-            external_repository_handle, 'external_respository_handle', RepositoryHandle
+            external_repository_handle, "external_respository_handle", RepositoryHandle
         )
         self._external_partition_set = check.inst_param(
-            external_partition_set, 'external_partition_set', ExternalPartitionSet
+            external_partition_set, "external_partition_set", ExternalPartitionSet
         )
 
         super(DauphinPartitionSet, self).__init__(
@@ -116,7 +133,7 @@ class DauphinPartitionSet(dauphin.ObjectType):
             self._external_partition_set,
             cursor=kwargs.get("cursor"),
             limit=kwargs.get("limit"),
-            reverse=kwargs.get('reverse'),
+            reverse=kwargs.get("reverse"),
         )
 
     def resolve_partition(self, graphene_info, partition_name):
@@ -130,50 +147,50 @@ class DauphinPartitionSet(dauphin.ObjectType):
 
 class DapuphinPartitionSetOrError(dauphin.Union):
     class Meta(object):
-        name = 'PartitionSetOrError'
-        types = ('PartitionSet', DauphinPartitionSetNotFoundError, DauphinPythonError)
+        name = "PartitionSetOrError"
+        types = ("PartitionSet", DauphinPartitionSetNotFoundError, DauphinPythonError)
 
 
 class DauphinPartitionSets(dauphin.ObjectType):
     class Meta(object):
-        name = 'PartitionSets'
+        name = "PartitionSets"
 
-    results = dauphin.non_null_list('PartitionSet')
+    results = dauphin.non_null_list("PartitionSet")
 
 
 class DauphinPartitionTags(dauphin.ObjectType):
     class Meta(object):
-        name = 'PartitionTags'
+        name = "PartitionTags"
 
-    results = dauphin.non_null_list('PipelineTag')
+    results = dauphin.non_null_list("PipelineTag")
 
 
 class DauphinPartitionRunConfig(dauphin.ObjectType):
     class Meta(object):
-        name = 'PartitionRunConfig'
+        name = "PartitionRunConfig"
 
     yaml = dauphin.NonNull(dauphin.String)
 
 
 class DauphinPartitionSetsOrError(dauphin.Union):
     class Meta(object):
-        name = 'PartitionSetsOrError'
+        name = "PartitionSetsOrError"
         types = (DauphinPartitionSets, DauphinPipelineNotFoundError, DauphinPythonError)
 
 
 class DauphinPartitionsOrError(dauphin.Union):
     class Meta(object):
-        name = 'PartitionsOrError'
+        name = "PartitionsOrError"
         types = (DauphinPartitions, DauphinPythonError)
 
 
 class DauphinPartitionTagsOrError(dauphin.Union):
     class Meta(object):
-        name = 'PartitionTagsOrError'
+        name = "PartitionTagsOrError"
         types = (DauphinPartitionTags, DauphinPythonError)
 
 
 class DauphinPartitionRunConfigOrError(dauphin.Union):
     class Meta(object):
-        name = 'PartitionRunConfigOrError'
+        name = "PartitionRunConfigOrError"
         types = (DauphinPartitionRunConfig, DauphinPythonError)
