@@ -32,16 +32,21 @@ class DauphinScheduleDefinition(dauphin.ObjectType):
     class Meta(object):
         name = "ScheduleDefinition"
 
+    id = dauphin.NonNull(dauphin.ID)
     name = dauphin.NonNull(dauphin.String)
     cron_schedule = dauphin.NonNull(dauphin.String)
     pipeline_name = dauphin.NonNull(dauphin.String)
     solid_selection = dauphin.List(dauphin.String)
     mode = dauphin.NonNull(dauphin.String)
+    execution_timezone = dauphin.Field(dauphin.String)
     schedule_state = dauphin.Field("ScheduleState")
 
     runConfigOrError = dauphin.Field("ScheduleRunConfigOrError")
     partition_set = dauphin.Field("PartitionSet")
 
+    def resolve_id(self, _):
+        return "%s:%s" % (self.name, self.pipeline_name)
+
     def resolve_runConfigOrError(self, graphene_info):
         return get_schedule_config(graphene_info, self._external_schedule)
 
@@ -65,10 +70,15 @@ class DauphinScheduleDefinition(dauphin.ObjectType):
         self._external_schedule = check.inst_param(
             external_schedule, "external_schedule", ExternalSchedule
         )
-        self._schedule_state = graphene_info.context.instance.get_schedule_state(
+        self._schedule_state = graphene_info.context.instance.get_stored_schedule_state(
             self._external_schedule.get_origin_id()
         )
 
+        if not self._schedule_state:
+            # Also include a ScheduleState for a stopped schedule that may not
+            # have a stored database row yet
+            self._schedule_state = self._external_schedule.get_default_schedule_state()
+
         super(DauphinScheduleDefinition, self).__init__(
             name=external_schedule.name,
             cron_schedule=external_schedule.cron_schedule,
@@ -80,6 +90,7 @@ class DauphinScheduleDefinition(dauphin.ObjectType):
             )
             if self._schedule_state
             else None,
+            execution_timezone=self._external_schedule.execution_timezone,
         )
 
 
